@@ -27,6 +27,7 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #include <QGraphicsGridLayout>
 #include <QTimer>
 #include <QDBusConnection>
+#include <QCheckBox>
 
 // KDE
 #include <KDebug>
@@ -129,6 +130,7 @@ void NMPopup::init()
     m_wwanCheckBox = new Plasma::CheckBox(m_leftWidget);
     m_wwanCheckBox->setText(i18nc("CheckBox to enable or disable wwan (mobile broadband) interface)", "Enable mobile broadband"));
     m_wwanCheckBox->hide();
+    m_wwanCheckBox->nativeWidget()->setTristate(true);
     checkboxLayout->addItem(m_wwanCheckBox, 0, 1);
 
     connect(m_wwanCheckBox, SIGNAL(toggled(bool)), SLOT(wwanEnabledToggled(bool)));
@@ -299,7 +301,7 @@ void NMPopup::readConfig()
     m_showMoreButton->setEnabled(Solid::Control::NetworkManagerNm09::isNetworkingEnabled() &&
                                  Solid::Control::NetworkManagerNm09::isWirelessEnabled());
 
-    m_wwanCheckBox->setChecked(Solid::Control::NetworkManagerNm09::isWwanEnabled());
+    m_wwanCheckBox->nativeWidget()->setCheckState(Solid::Control::NetworkManagerNm09::isWwanEnabled() ? Qt::Checked : Qt::Unchecked);
     m_wwanCheckBox->setEnabled(Solid::Control::NetworkManagerNm09::isWwanHardwareEnabled());
 
     foreach(InterfaceItem * i, m_interfaces) {
@@ -526,7 +528,7 @@ kDebug() << "Wireless hardware enabled ==" << Solid::Control::NetworkManagerNm09
     m_wifiCheckBox->setEnabled(Solid::Control::NetworkManagerNm09::isWirelessHardwareEnabled() || Solid::Control::NetworkManagerNm09::isWirelessEnabled());
 #endif
 
-    m_wwanCheckBox->setChecked(Solid::Control::NetworkManagerNm09::isWwanEnabled());
+    m_wwanCheckBox->nativeWidget()->setCheckState(Solid::Control::NetworkManagerNm09::isWwanEnabled() ? Qt::Checked : Qt::Unchecked);
     m_wwanCheckBox->setEnabled(Solid::Control::NetworkManagerNm09::isWwanHardwareEnabled() || Solid::Control::NetworkManagerNm09::isWwanEnabled());
 
     updateHasWireless(checked);
@@ -618,7 +620,7 @@ void NMPopup::managerNetworkingEnabledChanged(bool enabled)
 void NMPopup::managerWwanEnabledChanged(bool enabled)
 {
     kDebug() << "NM daemon changed wwan enable state" << enabled;
-    m_wwanCheckBox->setChecked(enabled);
+    m_wwanCheckBox->nativeWidget()->setCheckState(enabled ? Qt::Checked : Qt::Unchecked);
     if (enabled) {
         m_wwanCheckBox->setEnabled(enabled);
     }
@@ -691,7 +693,7 @@ void NMPopup::uncheckShowMore(RemoteActivatable *ra)
         }
         wicCount++;
         if (m_oldShowMoreChecked != m_showMoreChecked) {
-            // One wireless network explicity configured by the user appeared, reset "Show More" button
+            // One wireless network explicitly configured by the user appeared, reset "Show More" button
             // state to the value before the checkShowMore method above took action.
             showMore(m_oldShowMoreChecked);
         }
