@@ -370,23 +370,7 @@ void NMDBusSettingsConnectionProvider::updateConnection(const QString &uuid, Knm
         newConnection->setUuid(uuid);
         ConnectionDbus converter(newConnection);
         QVariantMapMap map = converter.toDbusMap();
-
-        if (newConnection->name() == remote->id()) {
-            remote->Update(map);
-        } else {
-            /* If connection's name (id in NM's termonology) changes during an Update
-             * NM will leave the old connection file intact and create a new connection file
-             * in /etc/NetworkManager/system-connections/ with the same uuid, which is wrong in my oppinion.
-             * Furthermore the old connection will not be shown in Plasma NM's connection list
-             * because we use connection's uuid as connection identifier.
-             * Deleting the old connection and creating a new one seems to work.
-             */
-            kDebug() << "Renaming connection:" << remote->id() << " -> " << newConnection->name();
-            QDBusPendingCall reply = remote->Delete();
-            reply.waitForFinished();
-            sleep(1);
-            addConnection(newConnection);
-        }
+        remote->Update(map);
 
         // don't do any processing on d->connections and d->connectionList here
         // because onRemoteConnectionUpdated() method will take care of them
@@ -438,12 +422,18 @@ void NMDBusSettingsConnectionProvider::onConnectionAddArrived(QDBusPendingCallWa
         // This does not work for VPN connections.
         // TODO: change this to a dbus call to the kded module.
         QString uuid = d->uuidToPath.key(objPath.path(), QUuid()).toString();
-        RemoteConnection *remote = d->connections.value(uuid);
+        if (uuid.isNull()) {
+            initialiseAndRegisterRemoteConnection(objPath.path());
+        }
+        uuid = d->uuidToPath.key(objPath.path(), QUuid()).toString();
         QVariantMapMap map = d->secretsToSave.take(uuid);
-        sleep(1);
-        remote->Update(map);
-        emit addConnectionCompleted(true, QString());
+        RemoteConnection *remote = d->connections.value(uuid);
+        if (remote) {
+            sleep(1);
+            remote->Update(map);
+        }
 
+        emit addConnectionCompleted(true, QString());
         kDebug() << "Connection added successfully: " << objPath.path() << uuid;
     }
 
