@@ -541,16 +541,16 @@ void ManageConnectionWidget::editGotSecrets(bool valid, const QString &errorMess
             KMessageBox::error(this, errorMessage);
     }
 
-    kDebug() << uuid << mEditConnection->uuid();
-
-    if (uuid != mEditConnection->uuid()) {
+    if (!mEditConnection || mEditConnection->uuid() != uuid) {
         return;
     }
 
+    kDebug() << uuid << mEditConnection->uuid();
     Knm::Connection *result = mEditor->editConnection(mEditConnection); //starts editor window
     if (result) {
         mSystemSettings->updateConnection(mEditConnection->uuid().toString(), result);
     }
+
     delete mEditConnection;
     mEditConnection = 0;
 }
